| Title: | Class and Methods Definitions for Packages 'aws', 'adimpro', 'fmri', 'dwi' |
|---|---|
| Description: | Defines the method extract and provides 'openMP' support as needed in several packages. |
| Authors: | Joerg Polzehl [aut, cre], Felix Anker [ctb] |
| Maintainer: | Joerg Polzehl <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.1-1 |
| Built: | 2026-06-01 07:22:28 UTC |
| Source: | https://github.com/cran/awsMethods |
extract
Provides generic function extract currently used in
packages aws and dti.
Method extract is used to extract information from objects
defined in packages aws and dti. Here only the generic function is
defined. The method usually takes an argument what='vector of characters'
defining which information is needed and returns a list with component names corresponding
to the entries in what.
signature(x = "ANY")risk
Provides generic function risk currently used in
package aws.
Defines a method used in package aws to evaluate the
quality of smoothing results. See help in package aws for details.
signature(y = "ANY")The function sets the number of cores used in openMP parallelization in part of the Fortran code.
setCores(n, reprt = TRUE)setCores(n, reprt = TRUE)
n |
number of cores to use. If |
reprt |
Logical, is |
The number of cores is restricted to integers between 1 (default) and the number of available cores.
The function returns the number of cores in use.
This function is a slightly modified version of function setCores in package spMC version 0.2.2 written by Luca Sartore <[email protected]>
Felix Anker ([email protected])
## Report number of cores available and in use setCores() ## Set number of cores used in openMP to minimum of ## 12 and number of available cores setCores(12)## Report number of cores available and in use setCores() ## Set number of cores used in openMP to minimum of ## 12 and number of available cores setCores(12)